==> react_image_annotate_ns_workflow-4.0.4.tgz: package/Annotator/reducers/history-handler.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import moment from "moment";
import { asMutable, setIn, updateIn, without } from "seamless-immutable";
import getActiveImage from "./get-active-image";
var typesToSaveWithHistory = {
  BEGIN_BOX_TRANSFORM: "Transform/Move Box",
  BEGIN_MOVE_POINT: "Move Point",
  DELETE_REGION: "Delete Region"
};
export var saveToHistory = function saveToHistory(state, name) {
  var History = asMutable(state.history).length;
  window.undoArray = _toConsumableArray(new Set([].concat(_toConsumableArray(window.undoArray), [name + History])));
  return updateIn(state, ["history"], function (h) {
    return [{
      time: moment().toDate(),
      state: without(state, "history"),
      name: name
    }].concat((h || []).slice(0, 9));
  });
};
export default (function (reducer) {
  return function (state, action) {
    var prevState = state;
    var nextState = reducer(state, action);

    if (action.type === "REDO_HISTORY") {
      var redoData = _toConsumableArray(window.annotation_redo);

      var getlastIndexValue = redoData[redoData.length - 1].annotation;

      var _state = saveToHistory(nextState, getlastIndexValue.name);

      var _getActiveImage = getActiveImage(_state),
          pathToActiveImage = _getActiveImage.pathToActiveImage;

      var newArr = _toConsumableArray(window.annotation_redo);

      newArr.splice(window.annotation_redo.length - 1, 2);
      window.annotation_redo = newArr;
      return setIn(_state, [].concat(_toConsumableArray(pathToActiveImage), ["regions"]), getlastIndexValue.regionsArr);
    }

    if (action.type === "RESTORE_HISTORY") {
      if (state.history.length > 0) {
        var history_return = function history_return() {
          var _state$images;

          var obj = {};

          if (nextState.annotationType === "video") {
            var _nextState$history, _nextState$keyframes, _nextState$keyframes$;

            obj = {
              annotation: _objectSpread({}, nextState === null || nextState === void 0 ? void 0 : (_nextState$history = nextState.history) === null || _nextState$history === void 0 ? void 0 : _nextState$history[0], {
                regionsArr: nextState === null || nextState === void 0 ? void 0 : (_nextState$keyframes = nextState.keyframes) === null || _nextState$keyframes === void 0 ? void 0 : (_nextState$keyframes$ = _nextState$keyframes[nextState.currentVideoTime]) === null || _nextState$keyframes$ === void 0 ? void 0 : _nextState$keyframes$.regions
              })
            };
          } else {
            var _nextState$history2, _nextState$images, _nextState$images$;

            obj = {
              annotation: _objectSpread({}, nextState === null || nextState === void 0 ? void 0 : (_nextState$history2 = nextState.history) === null || _nextState$history2 === void 0 ? void 0 : _nextState$history2[0], {
                regionsArr: nextState === null || nextState === void 0 ? void 0 : (_nextState$images = nextState.images) === null || _nextState$images === void 0 ? void 0 : (_nextState$images$ = _nextState$images[0]) === null || _nextState$images$ === void 0 ? void 0 : _nextState$images$.regions
              })
            };
          }

          (_state$images = state.images) === null || _state$images === void 0 ? void 0 : _state$images[0].regions.map(function (r, index) {
            if (!r.cls || r.cls === "") {
              window.onChangeOCR(index, "label_undo", "");
            }
          });
          window.annotation_redo = [].concat(_toConsumableArray(window.annotation_redo), [obj]);
          return setIn(nextState.history[0].state, ["history"], nextState.history.slice(1));
        };

        return history_return();
      }
    } else {
      if (prevState !== nextState && Object.keys(typesToSaveWithHistory).includes(action.type)) {
        return setIn(nextState, ["history"], [{
          time: moment().toDate(),
          state: without(prevState, "history"),
          name: typesToSaveWithHistory[action.type] || action.type
        }].concat(nextState.history || []).slice(0, 9));
      }
    }

    return nextState;
  };
});

==> react_image_annotate_ns_workflow-4.0.8.tgz: package/Annotator/reducers/history-handler.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import moment from "moment";
import { asMutable, setIn, updateIn, without } from "seamless-immutable";
import getActiveImage from "./get-active-image";
var typesToSaveWithHistory = {
  BEGIN_BOX_TRANSFORM: "Transform/Move Box",
  BEGIN_MOVE_POINT: "Move Point",
  DELETE_REGION: "Delete Region"
};
export var saveToHistory = function saveToHistory(state, name) {
  var History = asMutable(state.history).length;
  window.undoArray = _toConsumableArray(new Set([].concat(_toConsumableArray(window.undoArray), [name + History])));
  return updateIn(state, ["history"], function (h) {
    return [{
      time: moment().toDate(),
      state: without(state, "history"),
      name: name
    }].concat((h || []).slice(0, 9));
  });
};
export default (function (reducer) {
  return function (state, action) {
    var prevState = state;
    var nextState = reducer(state, action);
    if (action.type === "REDO_HISTORY") {
      var redoData = _toConsumableArray(window.annotation_redo);
      var getlastIndexValue = redoData[redoData.length - 1].annotation;
      var _state = saveToHistory(nextState, getlastIndexValue.name);
      var _getActiveImage = getActiveImage(_state),
        pathToActiveImage = _getActiveImage.pathToActiveImage;
      var newArr = _toConsumableArray(window.annotation_redo);
      newArr.splice(window.annotation_redo.length - 1, 2);
      window.annotation_redo = newArr;
      return setIn(_state, [].concat(_toConsumableArray(pathToActiveImage), ["regions"]), getlastIndexValue.regionsArr);
    }
    if (action.type === "RESTORE_HISTORY") {
      if (state.history.length > 0) {
        var history_return = function history_return() {
          var _state$images, _state$images$, _state$images$$region;
          var obj = {};
          if (nextState.annotationType === "video") {
            var _nextState$history, _nextState$keyframes, _nextState$keyframes$;
            obj = {
              annotation: _objectSpread({}, nextState === null || nextState === void 0 ? void 0 : (_nextState$history = nextState.history) === null || _nextState$history === void 0 ? void 0 : _nextState$history[0], {
                regionsArr: nextState === null || nextState === void 0 ? void 0 : (_nextState$keyframes = nextState.keyframes) === null || _nextState$keyframes === void 0 ? void 0 : (_nextState$keyframes$ = _nextState$keyframes[nextState.currentVideoTime]) === null || _nextState$keyframes$ === void 0 ? void 0 : _nextState$keyframes$.regions
              })
            };
          } else {
            var _nextState$history2, _nextState$images, _nextState$images$;
            obj = {
              annotation: _objectSpread({}, nextState === null || nextState === void 0 ? void 0 : (_nextState$history2 = nextState.history) === null || _nextState$history2 === void 0 ? void 0 : _nextState$history2[0], {
                regionsArr: nextState === null || nextState === void 0 ? void 0 : (_nextState$images = nextState.images) === null || _nextState$images === void 0 ? void 0 : (_nextState$images$ = _nextState$images[0]) === null || _nextState$images$ === void 0 ? void 0 : _nextState$images$.regions
              })
            };
          }
          state === null || state === void 0 ? void 0 : (_state$images = state.images) === null || _state$images === void 0 ? void 0 : (_state$images$ = _state$images[0]) === null || _state$images$ === void 0 ? void 0 : (_state$images$$region = _state$images$.regions) === null || _state$images$$region === void 0 ? void 0 : _state$images$$region.map(function (r, index) {
            if (!r.cls || r.cls === "") {
              window.onChangeOCR(index, "label_undo", "");
            }
          });
          window.annotation_redo = [].concat(_toConsumableArray(window.annotation_redo), [obj]);
          return setIn(nextState.history[0].state, ["history"], nextState.history.slice(1));
        };
        return history_return();
      }
    } else {
      if (prevState !== nextState && Object.keys(typesToSaveWithHistory).includes(action.type)) {
        return setIn(nextState, ["history"], [{
          time: moment().toDate(),
          state: without(prevState, "history"),
          name: typesToSaveWithHistory[action.type] || action.type
        }].concat(nextState.history || []).slice(0, 9));
      }
    }
    return nextState;
  };
});
